searchData={"items":[{"type":"module","title":"ExAequoFn","doc":"Functional helpers\n\n### `const_fn`\n\nA function that returns a const\n\nIgnoring up to 3 additional args, returning a const\n\n    iex(1)> const_fn(1).()\n    1\n\n    iex(2)> const_fn(2, 1)\n    2\n\n    iex(3)> const_fn(:a, 1, 2)\n    :a\n\n    iex(4)> const_fn(nil, 1, :a, [])\n    nil\n\n### `named_fn`\n\nBy default they have arity 1\n\n    iex(5)> add1 = named_fn(&(&1+1), \"add1\")\n    ...(5)> assert add1.name == \"add1\"\n    ...(5)> assert NamedFn.call(add1, 41) == 42\n    ...(5)> assert NamedFn.call(add1, [41]) == 42\n\nThey can be curried, (but that might not be very useful with arity 1)\n\n    iex(6)> add1 = named_fn(&(&1+1), \"add_one\")\n    ...(6)> assert is_function(NamedFn.call(add1))\n    ...(6)> assert is_function(NamedFn.call(add1, []))\n    ...(6)> NamedFn.call(add1).(72)\n    73\n\nBut more useful with higher arities\n\n    iex(7)> adder = named_fn(&(&1+&2), \"adder\")\n    ...(7)> assert is_function(NamedFn.call(adder))\n    ...(7)> add42 = NamedFn.call(adder, 42)\n    ...(7)> add42.(31)\n    73\n\nMore examples can be found in the doctests of `NamedFn`\n\n### `nil_fn`\n\nShort for `const_fn(nil, ...)`\n\n    iex(8)> nil_fn()\n    nil\n\n    iex(9)> nil_fn(42)\n    nil\n\n    iex(10)> nil_fn({:a, :b}, \"hello\")\n    nil\n\n    iex(11)> nil_fn([], \"hello\", %{})\n    nil\n\n ### `tagged_fn`\n\n A function that wraps the result of `const_fn` into a tagged tuple\n\n    iex(12)> tagged_fn(:alpha).(\"beta\")\n    {:alpha, \"beta\"}\n\n ### `transform_many`\n\n delegates to `ExAequoFn.Transformer.many` (see below for details)","ref":"ExAequoFn.html"},{"type":"type","title":"ExAequoFn.binary?/0","doc":"","ref":"ExAequoFn.html#t:binary?/0"},{"type":"function","title":"ExAequoFn.const_fn/1","doc":"","ref":"ExAequoFn.html#const_fn/1"},{"type":"function","title":"ExAequoFn.const_fn/2","doc":"","ref":"ExAequoFn.html#const_fn/2"},{"type":"function","title":"ExAequoFn.const_fn/3","doc":"","ref":"ExAequoFn.html#const_fn/3"},{"type":"function","title":"ExAequoFn.const_fn/4","doc":"","ref":"ExAequoFn.html#const_fn/4"},{"type":"type","title":"ExAequoFn.either_t/2","doc":"","ref":"ExAequoFn.html#t:either_t/2"},{"type":"type","title":"ExAequoFn.function_t/0","doc":"","ref":"ExAequoFn.html#t:function_t/0"},{"type":"type","title":"ExAequoFn.maybe/1","doc":"","ref":"ExAequoFn.html#t:maybe/1"},{"type":"function","title":"ExAequoFn.named_fn/2","doc":"See  ExAequoFn.NamedFn.new/2 .","ref":"ExAequoFn.html#named_fn/2"},{"type":"function","title":"ExAequoFn.nil_fn/0","doc":"","ref":"ExAequoFn.html#nil_fn/0"},{"type":"function","title":"ExAequoFn.nil_fn/1","doc":"","ref":"ExAequoFn.html#nil_fn/1"},{"type":"function","title":"ExAequoFn.nil_fn/2","doc":"","ref":"ExAequoFn.html#nil_fn/2"},{"type":"function","title":"ExAequoFn.nil_fn/3","doc":"","ref":"ExAequoFn.html#nil_fn/3"},{"type":"type","title":"ExAequoFn.result_t/1","doc":"","ref":"ExAequoFn.html#t:result_t/1"},{"type":"type","title":"ExAequoFn.stream_t/0","doc":"","ref":"ExAequoFn.html#t:stream_t/0"},{"type":"function","title":"ExAequoFn.tagged_fn/1","doc":"","ref":"ExAequoFn.html#tagged_fn/1"},{"type":"function","title":"ExAequoFn.transform_many/2","doc":"See  ExAequoFn.Transformer.many/2 .","ref":"ExAequoFn.html#transform_many/2"},{"type":"type","title":"ExAequoFn.transformer_t/0","doc":"","ref":"ExAequoFn.html#t:transformer_t/0"},{"type":"type","title":"ExAequoFn.transformers_t/0","doc":"","ref":"ExAequoFn.html#t:transformers_t/0"},{"type":"module","title":"ExAequoFn.NamedFn","doc":"A function wrapper","ref":"ExAequoFn.NamedFn.html"},{"type":"type","title":"ExAequoFn.NamedFn.binary?/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:binary?/0"},{"type":"function","title":"ExAequoFn.NamedFn.call/1","doc":"Same as `call(..., [])`, basically extracting fun","ref":"ExAequoFn.NamedFn.html#call/1"},{"type":"function","title":"ExAequoFn.NamedFn.call/2","doc":"This can also curry into a function\n\n      iex(1)> join3 = new(&Enum.join([&1, &2, &3], \"-\"), \"joiner\")\n      ...(1)> join2 = call(join3, ~W[a])\n      ...(1)> assert join2.(~W[b c]) == \"a-b-c\"\n\nBut be careful with arg sizes\n\n      iex(2)> adder = new(&(&1 + &2))\n      ...(2)> assert_raise(ArgumentError, fn -> call(adder, [1, 2, 3]) end)","ref":"ExAequoFn.NamedFn.html#call/2"},{"type":"type","title":"ExAequoFn.NamedFn.either_t/2","doc":"","ref":"ExAequoFn.NamedFn.html#t:either_t/2"},{"type":"type","title":"ExAequoFn.NamedFn.function_t/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:function_t/0"},{"type":"type","title":"ExAequoFn.NamedFn.maybe/1","doc":"","ref":"ExAequoFn.NamedFn.html#t:maybe/1"},{"type":"function","title":"ExAequoFn.NamedFn.new/2","doc":"","ref":"ExAequoFn.NamedFn.html#new/2"},{"type":"type","title":"ExAequoFn.NamedFn.result_t/1","doc":"","ref":"ExAequoFn.NamedFn.html#t:result_t/1"},{"type":"type","title":"ExAequoFn.NamedFn.stream_t/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:stream_t/0"},{"type":"type","title":"ExAequoFn.NamedFn.t/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:t/0"},{"type":"type","title":"ExAequoFn.NamedFn.transformer_t/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:transformer_t/0"},{"type":"type","title":"ExAequoFn.NamedFn.transformers_t/0","doc":"","ref":"ExAequoFn.NamedFn.html#t:transformers_t/0"},{"type":"module","title":"ExAequoFn.Stream","doc":"","ref":"ExAequoFn.Stream.html"},{"type":"type","title":"ExAequoFn.Stream.binary?/0","doc":"","ref":"ExAequoFn.Stream.html#t:binary?/0"},{"type":"type","title":"ExAequoFn.Stream.either_t/2","doc":"","ref":"ExAequoFn.Stream.html#t:either_t/2"},{"type":"type","title":"ExAequoFn.Stream.function_t/0","doc":"","ref":"ExAequoFn.Stream.html#t:function_t/0"},{"type":"type","title":"ExAequoFn.Stream.maybe/1","doc":"","ref":"ExAequoFn.Stream.html#t:maybe/1"},{"type":"function","title":"ExAequoFn.Stream.next/1","doc":"Advances and returns head\n\n    iex(1)> enum = 1..3\n    ...(1)> {1, s} = next(enum)\n    ...(1)> s |> Enum.to_list \n    [2, 3]\n\nAt the end we get nil\n\n    \n    iex(2)> {1, s} = next([1]) \n    ...(2)> next(s)\n    nil","ref":"ExAequoFn.Stream.html#next/1"},{"type":"type","title":"ExAequoFn.Stream.result_t/1","doc":"","ref":"ExAequoFn.Stream.html#t:result_t/1"},{"type":"type","title":"ExAequoFn.Stream.stream_t/0","doc":"","ref":"ExAequoFn.Stream.html#t:stream_t/0"},{"type":"type","title":"ExAequoFn.Stream.transformer_t/0","doc":"","ref":"ExAequoFn.Stream.html#t:transformer_t/0"},{"type":"type","title":"ExAequoFn.Stream.transformers_t/0","doc":"","ref":"ExAequoFn.Stream.html#t:transformers_t/0"},{"type":"function","title":"ExAequoFn.Stream.zipn/1","doc":"","ref":"ExAequoFn.Stream.html#zipn/1"},{"type":"module","title":"ExAequoFn.Transformer","doc":"Implements functional transformation helpers\n\n### `many`\n\n`many` takes a list and a list of transsformers. A transformer is simply a function\nthat returns either `{:ok, value}` or `:error`\n\nThe list is traversed by calling all transformers on each element of the list until\nthe first transformer returns an `{:ok, value}` tuple in which case the element is\nreplaced by `value`. If a transformer returning an `:ok` value is found for **all**\nelements, then the tuple `{:ok, [transformed values,...]}` is returned, otherwise\n`:error` is returned\n\n    iex(1)> ft = %{a: 1, b: 2}\n    ...(1)> st = %{a: 2, x: 3}\n    ...(1)> ff = &Map.fetch(ft, &1)\n    ...(1)> sf = &Map.fetch(st, &1)\n    ...(1)> assert many([:a, :x], [ff, sf]) == {:ok, [1, 3]}\n    ...(1)> assert many([:a, :z], [ff, sf]) == :error","ref":"ExAequoFn.Transformer.html"},{"type":"type","title":"ExAequoFn.Transformer.binary?/0","doc":"","ref":"ExAequoFn.Transformer.html#t:binary?/0"},{"type":"type","title":"ExAequoFn.Transformer.either_t/2","doc":"","ref":"ExAequoFn.Transformer.html#t:either_t/2"},{"type":"type","title":"ExAequoFn.Transformer.function_t/0","doc":"","ref":"ExAequoFn.Transformer.html#t:function_t/0"},{"type":"function","title":"ExAequoFn.Transformer.many/2","doc":"","ref":"ExAequoFn.Transformer.html#many/2"},{"type":"type","title":"ExAequoFn.Transformer.maybe/1","doc":"","ref":"ExAequoFn.Transformer.html#t:maybe/1"},{"type":"type","title":"ExAequoFn.Transformer.result_t/1","doc":"","ref":"ExAequoFn.Transformer.html#t:result_t/1"},{"type":"type","title":"ExAequoFn.Transformer.stream_t/0","doc":"","ref":"ExAequoFn.Transformer.html#t:stream_t/0"},{"type":"type","title":"ExAequoFn.Transformer.transformer_t/0","doc":"","ref":"ExAequoFn.Transformer.html#t:transformer_t/0"},{"type":"type","title":"ExAequoFn.Transformer.transformers_t/0","doc":"","ref":"ExAequoFn.Transformer.html#t:transformers_t/0"},{"type":"module","title":"ExAequoFn.Types","doc":"Types of this project","ref":"ExAequoFn.Types.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}